
#delimit ;

version 12.0;
drop _all;
set more off;
set linesize 200;


capture log close;
log using analysis_replication.txt, replace text;

set seed 1;

*Figure 1;


*First Make Figure 1a (Government Spending);

use replication_dataset_govspend.dta, clear;

gen x1 = govt_expend_ordinary/1000000;
gen x2 = govt_expend_1870_prices/1000000;

label var x1 "Nominal Spending";
label var x2 "Real Spending, 1870 Prices";

scatter x1 x2 year if year>=1850, s(o o) c(l l) lpattern(solid dash) xlabel(1850 1855 1860 1865 1870 1875 1880) ylabel(0 200 400 600 800 1000 1200) xtitle(Year) ytitle(Spending in Millions);
graph export fedl_govt_spending.pdf, replace;
graph export fedl_govt_spending.tif, replace;
*Then Make Figure 1b (Corruption Reporting);

use replication_dataset_newscorr.dta, clear;
twoway (area c year, bcolor(gs7)) (line cfjan3yr year , clpattern(solid)) if year>=1850, xlabel(1850 1855 1860 1865 1870 1875) legend(off) xtitle(Year) ytitle(Reporting on Corruption) saving(report, replace);
graph export corruption_report.pdf, replace;
graph export corruption_report.tif, replace;


*Figure 2;

use replication_dataset_main, clear;

drop if ran_1860s==0;

*Generate bin average and medians;

gen margin_group=.;
forvalues i=0.45(0.003)0.55{;
local j=`i'+0.003;
replace margin_group=`i' if fvs_1860s>=`i'&fvs_1860s<`j';
};

replace C_total_1860_1870= C_total_1860_1870/1000;

egen CY_total_med_cw = median(C_total_1860_1870) if ran_civwar==1, by(margin_group);
egen CY_total_med_nw = median(C_total_1860_1870) if ran_nonwar==1, by(margin_group);

egen C_servants_mean_cw = mean(C_servants_1860_1870) if ran_civwar==1, by(margin_group);
egen C_servants_mean_nw = mean(C_servants_1860_1870) if ran_nonwar==1, by(margin_group);

*Run Regression for fitted median line;

qreg C_total_1860_1870 fvs_1860s_d_1 fvs_1860s_d_1_w winner_nonwar_wf winner_civwar_wf if abs(fvs_1860s-0.5)<0.05;
local slope1_oall=_b[fvs_1860s_d_1];
local slope2_oall=_b[fvs_1860s_d_1_w];
local intercept1_oall=_b[_cons];
local intercept2_civwar_oall=_b[_cons]+_b[winner_civwar_wf];
local intercept2_nonwar_oall=_b[_cons]+_b[winner_nonwar_wf];

*Bootsrap standard errors of intercepts;

bootstrap oall1=(_b[_cons]), reps(100): qreg C_total_1860_1870 fvs_1860s_d_1 fvs_1860s_d_1_w winner_nonwar_wf winner_civwar_wf if abs(fvs_1860s-0.5)<0.05;
matrix oall_ci_1=e(ci_normal);
local lc1_oall=oall_ci_1[1,1];
local uc1_oall=oall_ci_1[2,1];

bootstrap civwar2_oall=(_b[_cons]+_b[winner_civwar_wf]), reps(100): qreg C_total_1860_1870 fvs_1860s_d_1 fvs_1860s_d_1_w winner_nonwar_wf winner_civwar_wf if abs(fvs_1860s-0.5)<0.05;
matrix civwar_ci_2_oall=e(ci_normal);
local lc2_civwar_oall=civwar_ci_2_oall[1,1];
local uc2_civwar_oall=civwar_ci_2_oall[2,1];

bootstrap nonwar2_oall=(_b[_cons]+_b[winner_nonwar_wf]), reps(100): qreg C_total_1860_1870 fvs_1860s_d_1 fvs_1860s_d_1_w winner_nonwar_wf winner_civwar_wf if abs(fvs_1860s-0.5)<0.05;
matrix nonwar_ci_2_oall=e(ci_normal);
local lc2_nonwar_oall=nonwar_ci_2_oall[1,1];
local uc2_nonwar_oall=nonwar_ci_2_oall[2,1];

*Shift intercepts to show discontinuity around 0.5 rather than around 0;


local intercept1_new_oall=`intercept1_oall'-(0.5*`slope1_oall');
local intercept1_new_lb_oall=`lc1_oall'-(0.5*`slope1_oall');
local intercept1_new_ub_oall=`uc1_oall'-(0.5*`slope1_oall');

local intercept2_civwar_new_oall=`intercept2_civwar_oall'-(0.5*`slope2_oall');
local intercept2_civwar_new_lb_oall=`lc2_civwar_oall'-(0.5*`slope2_oall');
local intercept2_civwar_new_ub_oall=`uc2_civwar_oall'-(0.5*`slope2_oall');

local intercept2_nonwar_new_oall=`intercept2_nonwar_oall'-(0.5*`slope2_oall');
local intercept2_nonwar_new_lb_oall=`lc2_nonwar_oall'-(0.5*`slope2_oall');
local intercept2_nonwar_new_ub_oall=`uc2_nonwar_oall'-(0.5*`slope2_oall');

*Plot Figures;

twoway (scatter CY_total_med_cw margin_group if abs(fvs_1860s-0.5)<0.05&abs(CY_total_med_cw)<50,msize(vsmall)) (function y=`intercept1_new_oall'+`slope1_oall'*x, range(0.45 0.5)) (function y=`intercept1_new_lb_oall'+`slope1_oall'*x, lpattern (dash) lcolor(gs10) lwidth(thin) range(0.45 0.5)) (function y=`intercept1_new_ub_oall'+`slope1_oall'*x, lpattern (dash) lcolor(gs10) lwidth(thin) range(0.45 0.5)) (function y=`intercept2_civwar_new_oall'+`slope2_oall'*x, range(0.50 0.55)) (function y=`intercept2_civwar_new_lb_oall'+`slope2_oall'*x, lpattern (dash) lcolor(gs10) lwidth(thin) range(0.50 0.55)) (function y=`intercept2_civwar_new_ub_oall'+`slope2_oall'*x, lpattern (dash) lcolor(gs10) lwidth(thin) range(0.50 0.55)), xline(0.5) legend(off) xtitle(Vote Share in First Race) ytitle("Change in Wealth, ($1,000)") title("Wealth, Civ War", size(medium)) xlabel(.45 .46 .47 .48 .49 .5 .51 .52 .53 .54 .55) saving(g1c, replace);
twoway (scatter CY_total_med_nw margin_group if abs(fvs_1860s-0.5)<0.05&abs(CY_total_med_nw)<50,msize(vsmall)) (function y=`intercept1_new_oall'+`slope1_oall'*x, range(0.45 0.5)) (function y=`intercept1_new_lb_oall'+`slope1_oall'*x, lpattern (dash) lcolor(gs10) lwidth(thin) range(0.45 0.5)) (function y=`intercept1_new_ub_oall'+`slope1_oall'*x, lpattern(dash) lcolor(gs10) lwidth(thin) range(0.45 0.5)) (function y=`intercept2_nonwar_new_oall'+`slope2_oall'*x, range(0.50 0.55)) (function y=`intercept2_nonwar_new_lb_oall'+`slope2_oall'*x, lpattern (dash) lcolor(gs10) lwidth(thin) range(0.50 0.55)) (function y=`intercept2_nonwar_new_ub_oall'+`slope2_oall'*x, lpattern (dash) lcolor(gs10) lwidth(thin) range(0.50 0.55)), xline(0.5) legend(off) xtitle(Vote Share in First Race) ytitle("Change in Wealth, ($1,000)") title("Wealth, Non War", size(medium)) xlabel(.45 .46 .47 .48 .49 .5 .51 .52 .53 .54 .55)  saving(g2c, replace);

twoway (scatter C_servants_mean_cw margin_group if abs(fvs_1860s-0.5)<0.05, msize(vsmall)) (lfitci C_servants_1860_1870 fvs_1860s if fvs_1860s<0.5&(ran_civwar==1), ciplot(rline) alpattern(dash) ) (lfitci C_servants_1860_1870 fvs_1860s if fvs_1860s>0.5&(ran_civwar==1), ciplot(rline)  alpattern(dash)) if abs(fvs_1860s-0.5)<0.05, xline(0.5) legend(off) xtitle(Vote Share in First Race) ytitle("Change in Servants") title("Servants, Civ War", size(medium)) xlabel(.45 .46 .47 .48 .49 .5 .51 .52 .53 .54 .55) saving(g3c, replace);
twoway (scatter C_servants_mean_nw margin_group if abs(fvs_1860s-0.5)<0.05, msize(vsmall)) (lfitci C_servants_1860_1870 fvs_1860s if fvs_1860s<0.5&(ran_nonwar==1), ciplot(rline) alpattern(dash)) (lfitci C_servants_1860_1870 fvs_1860s if fvs_1860s>0.5&(ran_nonwar==1), ciplot(rline) alpattern(dash)) if abs(fvs_1860s-0.5)<0.05, xline(0.5) legend(off) xtitle(Vote Share in First Race) ytitle("Change in Servants") title("Servants, Non War", size(medium)) xlabel(.45 .46 .47 .48 .49 .5 .51 .52 .53 .54 .55)  saving(g4c, replace);

graph combine g1c.gph g2c.gph, cols(2) ycommon imargin(vsmall) saving(wealth, replace);
graph combine g3c.gph g4c.gph, cols(2) ycommon imargin(vsmall) saving(servants, replace);
graph combine wealth.gph servants.gph, cols(1) imargin(vsmall);
graph export rdd_graphs_cw_nw.pdf, replace;
graph export rdd_graphs_cw_nw.tif, replace;
